voicetools.get_first_voice_in_proper_parentage_of_component
===========================================================

.. autofunction:: abjad.tools.voicetools.get_first_voice_in_proper_parentage_of_component.get_first_voice_in_proper_parentage_of_component
